@@ -33,12 +33,18 @@ test_that("tidy.boot for glms", {
 
   bootresw <- boot::boot(clotting, boot_fun, R = 100, weights = rep(1 / 9, 9))
   tdw <- tidy(bootresw, conf.int = TRUE)
+  tdwe <- tidy(bootresw, conf.int = TRUE, exponentiate = TRUE)
 
   check_tidy_output(td)
   check_tidy_output(tdw)
+  check_tidy_output(tdwe)
 
   check_dims(td, 2, 6)
-  check_dims(tdw, 2, 7)
+  check_dims(tdw,  2, 7)
+  check_dims(tdwe, 2, 7)
+  
+  expect_equal(exp(tdw$statistic), tdwe$statistic)
+  expect_equal(exp(tdw$conf.low), tdwe$conf.low)
 })
 
 test_that("tidy.boot for time series", {
